==> chaosmesh-model-6.4.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkDNSSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkDNSSpecFluentImpl<A extends NetworkDNSSpecFluent<A>> extends BaseFluent<A> implements NetworkDNSSpecFluent<A>{
  public NetworkDNSSpecFluentImpl() {
  }
  public NetworkDNSSpecFluentImpl(NetworkDNSSpec instance) {
    this.withDnsDomainName(instance.getDnsDomainName()); 
    this.withDnsIp(instance.getDnsIp()); 
    this.withDnsServer(instance.getDnsServer()); 
  }
  private String dnsDomainName;
  private String dnsIp;
  private String dnsServer;
  public String getDnsDomainName() {
    return this.dnsDomainName;
  }
  public A withDnsDomainName(String dnsDomainName) {
    this.dnsDomainName=dnsDomainName; return (A) this;
  }
  public Boolean hasDnsDomainName() {
    return this.dnsDomainName != null;
  }
  public String getDnsIp() {
    return this.dnsIp;
  }
  public A withDnsIp(String dnsIp) {
    this.dnsIp=dnsIp; return (A) this;
  }
  public Boolean hasDnsIp() {
    return this.dnsIp != null;
  }
  public String getDnsServer() {
    return this.dnsServer;
  }
  public A withDnsServer(String dnsServer) {
    this.dnsServer=dnsServer; return (A) this;
  }
  public Boolean hasDnsServer() {
    return this.dnsServer != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NetworkDNSSpecFluentImpl that = (NetworkDNSSpecFluentImpl) o;
    if (dnsDomainName != null ? !dnsDomainName.equals(that.dnsDomainName) :that.dnsDomainName != null) return false;
    if (dnsIp != null ? !dnsIp.equals(that.dnsIp) :that.dnsIp != null) return false;
    if (dnsServer != null ? !dnsServer.equals(that.dnsServer) :that.dnsServer != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(dnsDomainName,  dnsIp,  dnsServer,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (dnsDomainName != null) { sb.append("dnsDomainName:"); sb.append(dnsDomainName + ","); }
    if (dnsIp != null) { sb.append("dnsIp:"); sb.append(dnsIp + ","); }
    if (dnsServer != null) { sb.append("dnsServer:"); sb.append(dnsServer); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkDNSSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkDNSSpecFluentImpl<A extends NetworkDNSSpecFluent<A>> extends BaseFluent<A> implements NetworkDNSSpecFluent<A>{
  public NetworkDNSSpecFluentImpl() {
  }
  public NetworkDNSSpecFluentImpl(NetworkDNSSpec instance) {
    if (instance != null) {
      this.withDnsDomainName(instance.getDnsDomainName());
      this.withDnsIp(instance.getDnsIp());
      this.withDnsServer(instance.getDnsServer());
    }
  }
  private String dnsDomainName;
  private String dnsIp;
  private String dnsServer;
  public String getDnsDomainName() {
    return this.dnsDomainName;
  }
  public A withDnsDomainName(String dnsDomainName) {
    this.dnsDomainName=dnsDomainName; return (A) this;
  }
  public Boolean hasDnsDomainName() {
    return this.dnsDomainName != null;
  }
  public String getDnsIp() {
    return this.dnsIp;
  }
  public A withDnsIp(String dnsIp) {
    this.dnsIp=dnsIp; return (A) this;
  }
  public Boolean hasDnsIp() {
    return this.dnsIp != null;
  }
  public String getDnsServer() {
    return this.dnsServer;
  }
  public A withDnsServer(String dnsServer) {
    this.dnsServer=dnsServer; return (A) this;
  }
  public Boolean hasDnsServer() {
    return this.dnsServer != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkDNSSpecFluentImpl that = (NetworkDNSSpecFluentImpl) o;
    if (!java.util.Objects.equals(dnsDomainName, that.dnsDomainName)) return false;

    if (!java.util.Objects.equals(dnsIp, that.dnsIp)) return false;

    if (!java.util.Objects.equals(dnsServer, that.dnsServer)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(dnsDomainName,  dnsIp,  dnsServer,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (dnsDomainName != null) { sb.append("dnsDomainName:"); sb.append(dnsDomainName + ","); }
    if (dnsIp != null) { sb.append("dnsIp:"); sb.append(dnsIp + ","); }
    if (dnsServer != null) { sb.append("dnsServer:"); sb.append(dnsServer); }
    sb.append("}");
    return sb.toString();
  }
  
}
